@@ -95,7 +95,7 @@ def text(obj, carryForward=None):
 
 def link(attrs, carryForward=None):
     if gDebug: print("Parsing Link")
-    return "("+attrs.get("href")+")"
+    return " ("+attrs.get("href")+")"
 
 def mention(attrs, carryForward=None):
     if gDebug: print("Parsing Mention")
@@ -125,7 +125,7 @@ switcher = {
     "mention": (mention, 'attrs'),                              #Available only with type="text"
     "emoji": (emoji, 'attrs')                                   #Available only with type="text"        
 }
-replacers = ["\n\n\n\n", "\n\n\n", "\n\n"]
+replacers = ["\n\n\n\n\n", "\n\n\n\n", "\n\n\n", "\n\n"]
 
 
 #Driver Functions
